[Libreoffice-commits] .: basegfx/source canvas/inc comphelper/inc comphelper/source dtrans/source l10ntools/java l10ntools/source sax/source sot/source svl/inc svl/source svtools/bmpmaker svtools/source toolkit/qa tools/source ucbhelper/inc vcl/aqua vcl/inc vcl/source vcl/unx vcl/win

Caolán McNamara caolan at kemper.freedesktop.org
Sun Dec 5 11:06:11 PST 2010


 basegfx/source/workbench/gauss.hxx                                         |    2 -
 canvas/inc/canvas/rendering/irendermodule.hxx                              |    2 -
 comphelper/inc/comphelper/componentcontext.hxx                             |    8 +++---
 comphelper/inc/comphelper/docpasswordhelper.hxx                            |    2 -
 comphelper/inc/comphelper/embeddedobjectcontainer.hxx                      |    2 -
 comphelper/inc/comphelper/interaction.hxx                                  |    2 -
 comphelper/inc/comphelper/sequence.hxx                                     |    2 -
 comphelper/inc/comphelper/string.hxx                                       |    4 +--
 comphelper/source/misc/scopeguard.cxx                                      |    4 +--
 dtrans/source/cnttype/wbench/testcnttype.cxx                               |    2 -
 dtrans/source/win32/dtobj/DataFmtTransl.cxx                                |    2 -
 dtrans/source/win32/workbench/test_wincb.cxx                               |    2 -
 l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java   |    6 ++---
 l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java |    2 -
 l10ntools/source/filter/utils/Cache.java                                   |    2 -
 sax/source/expatwrap/saxwriter.cxx                                         |   12 +++++-----
 sot/source/sdstor/stgdir.cxx                                               |    2 -
 svl/inc/svl/zforlist.hxx                                                   |    2 -
 svl/source/numbers/zformat.cxx                                             |    2 -
 svtools/bmpmaker/bmp.cxx                                                   |    2 -
 svtools/source/brwbox/brwbox2.cxx                                          |    2 -
 svtools/source/dialogs/addresstemplate.cxx                                 |    2 -
 toolkit/qa/complex/toolkit/interface_tests/_XAccessibleComponent.java      |    6 ++---
 tools/source/fsys/dirent.cxx                                               |    2 -
 tools/source/fsys/os2.cxx                                                  |    2 -
 ucbhelper/inc/ucbhelper/resultset.hxx                                      |    4 +--
 vcl/aqua/source/dtrans/test_aquacb.cxx                                     |    2 -
 vcl/inc/vcl/pdfwriter.hxx                                                  |    6 ++---
 vcl/inc/vcl/print.hxx                                                      |    2 -
 vcl/inc/vcl/strhelper.hxx                                                  |    2 -
 vcl/source/control/ilstbox.cxx                                             |    4 +--
 vcl/unx/gtk/app/gtkdata.cxx                                                |    2 -
 vcl/unx/inc/saldisp.hxx                                                    |    4 +--
 vcl/unx/kde/kdedata.cxx                                                    |    2 -
 vcl/unx/kde4/KDEXLib.cxx                                                   |    2 -
 vcl/unx/source/app/saldata.cxx                                             |    4 +--
 vcl/unx/source/app/saldisp.cxx                                             |    4 +--
 vcl/unx/source/app/wmadaptor.cxx                                           |    4 +--
 vcl/unx/source/gdi/salbmp.cxx                                              |    2 -
 vcl/unx/source/window/FWS.cxx                                              |    2 -
 vcl/unx/source/window/salframe.cxx                                         |    6 ++---
 vcl/unx/source/window/salobj.cxx                                           |    4 +--
 vcl/win/source/window/salframe.cxx                                         |    4 +--
 43 files changed, 69 insertions(+), 69 deletions(-)

New commits:
commit 2ebfbf57882007458549f7f6c269d71aab485c16
Author: Takeshi Abe <tabe at fixedpoint.jp>
Date:   Sat Dec 4 13:22:40 2010 +0900

    Replace all occured, occurance etc.

diff --git a/basegfx/source/workbench/gauss.hxx b/basegfx/source/workbench/gauss.hxx
index d8196f1..74d6bfc 100644
--- a/basegfx/source/workbench/gauss.hxx
+++ b/basegfx/source/workbench/gauss.hxx
@@ -107,7 +107,7 @@ bool eliminate( 	Matrix&			matrix,
     Result vector. Given matrix must have space for one column (rows entries).
 
     @return true, if back substitution was possible (i.e. no division
-    by zero occured).
+    by zero occurred).
  */
 template <class Matrix, class Vector, typename BaseType> 
 bool substitute(	const Matrix&	matrix,
diff --git a/canvas/inc/canvas/rendering/irendermodule.hxx b/canvas/inc/canvas/rendering/irendermodule.hxx
index b3e4700..55e08d5 100644
--- a/canvas/inc/canvas/rendering/irendermodule.hxx
+++ b/canvas/inc/canvas/rendering/irendermodule.hxx
@@ -119,7 +119,7 @@ namespace canvas
 
         /** Query error status
 
-            @returns true, if an error occured during primitive
+            @returns true, if an error occurred during primitive
             construction.
          */
         virtual bool      isError() = 0;
diff --git a/comphelper/inc/comphelper/componentcontext.hxx b/comphelper/inc/comphelper/componentcontext.hxx
index 8a286b2..4b7c663 100644
--- a/comphelper/inc/comphelper/componentcontext.hxx
+++ b/comphelper/inc/comphelper/componentcontext.hxx
@@ -142,7 +142,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -153,7 +153,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -167,7 +167,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
@@ -181,7 +181,7 @@ namespace comphelper
             @throws ::com::sun::star::lang::ServiceNotRegisteredException
                 if the given service is not registered
             @throws Exception
-                if an exception occured during creating the component
+                if an exception occurred during creating the component
             @return
                 the newly created component. Is never <NULL/>.
         */
diff --git a/comphelper/inc/comphelper/docpasswordhelper.hxx b/comphelper/inc/comphelper/docpasswordhelper.hxx
index 7917f11..6262037 100644
--- a/comphelper/inc/comphelper/docpasswordhelper.hxx
+++ b/comphelper/inc/comphelper/docpasswordhelper.hxx
@@ -70,7 +70,7 @@ public:
             - DocPasswordVerifierResult_WRONG_PASSWORD, if the password is
               wrong. The user may be asked again for a new password.
             - DocPasswordVerifierResult_ABORT, if an unrecoverable error
-              occured while password verification. The password request loop
+              occurred while password verification. The password request loop
               will be aborted.
      */
     virtual DocPasswordVerifierResult verifyPassword( const ::rtl::OUString& rPassword ) = 0;
diff --git a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
index 7006cc6..447cede 100644
--- a/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
+++ b/comphelper/inc/comphelper/embeddedobjectcontainer.hxx
@@ -178,7 +178,7 @@ public:
     *
     * \param _xStorage The storeage where to store the objects.
     * \param _bClearModifedFlag If <TRUE/> then the modifed flag will be set to <FALSE/> otherwise nothing happen.
-    * \return <FALSE/> if no error occured, otherwise <TRUE/>.
+    * \return <FALSE/> if no error occurred, otherwise <TRUE/>.
     */
     sal_Bool             SetPersistentEntries(const com::sun::star::uno::Reference< com::sun::star::embed::XStorage >& _xStorage,bool _bClearModifedFlag = true);
 };
diff --git a/comphelper/inc/comphelper/interaction.hxx b/comphelper/inc/comphelper/interaction.hxx
index 1b233b1..87855fe 100644
--- a/comphelper/inc/comphelper/interaction.hxx
+++ b/comphelper/inc/comphelper/interaction.hxx
@@ -52,7 +52,7 @@ namespace comphelper
     */
     class OInteractionSelect
     {
-        sal_Bool	m_bSelected : 1;	/// indicates if the select event occured
+        sal_Bool	m_bSelected : 1;	/// indicates if the select event occurred
 
     protected:
         OInteractionSelect() : m_bSelected(sal_False) { }
diff --git a/comphelper/inc/comphelper/sequence.hxx b/comphelper/inc/comphelper/sequence.hxx
index 0d57913..10ec860 100644
--- a/comphelper/inc/comphelper/sequence.hxx
+++ b/comphelper/inc/comphelper/sequence.hxx
@@ -48,7 +48,7 @@ namespace comphelper
 
     //-------------------------------------------------------------------------
     /** search the given string within the given sequence, return the positions where it was found.
-        if _bOnlyFirst is sal_True, only the first occurence will be returned.
+        if _bOnlyFirst is sal_True, only the first occurrence will be returned.
     */
     COMPHELPER_DLLPUBLIC staruno::Sequence<sal_Int16> findValue(const staruno::Sequence< ::rtl::OUString >& _rList, const ::rtl::OUString& _rValue, sal_Bool _bOnlyFirst = sal_False);
 
diff --git a/comphelper/inc/comphelper/string.hxx b/comphelper/inc/comphelper/string.hxx
index 5101465..46faf87 100644
--- a/comphelper/inc/comphelper/string.hxx
+++ b/comphelper/inc/comphelper/string.hxx
@@ -75,14 +75,14 @@ COMPHELPER_DLLPUBLIC rtl::OUString searchAndReplaceAsciiL(
     rtl::OUString const & to, sal_Int32 beginAt = 0,
     sal_Int32 * replacedAt = NULL);
 
-/** replaces, in the given source string, all occurences of a given ASCII pattern
+/** replaces, in the given source string, all occurrences of a given ASCII pattern
     with another ASCII pattern
 */
 COMPHELPER_DLLPUBLIC ::rtl::OUString searchAndReplaceAllAsciiWithAscii(
     const ::rtl::OUString& source, const sal_Char* from, const sal_Char* to,
     const sal_Int32 beginAt = 0 );
 
-/** does an in-place replacement of the first occurance of a sub string with
+/** does an in-place replacement of the first occurrence of a sub string with
     another string
 
     @param source
diff --git a/comphelper/source/misc/scopeguard.cxx b/comphelper/source/misc/scopeguard.cxx
index c194e98..60062b2 100644
--- a/comphelper/source/misc/scopeguard.cxx
+++ b/comphelper/source/misc/scopeguard.cxx
@@ -49,11 +49,11 @@ ScopeGuard::~ScopeGuard()
                 OSL_ENSURE(
                     false, rtl::OUStringToOString(
                         rtl::OUString( RTL_CONSTASCII_USTRINGPARAM(
-                                           "UNO exception occured: ") ) +
+                                           "UNO exception occurred: ") ) +
                         exc.Message, RTL_TEXTENCODING_UTF8 ).getStr() );
             }
             catch (...) {
-                OSL_ENSURE( false, "unknown exception occured!" );
+                OSL_ENSURE( false, "unknown exception occurred!" );
             }
         }
         else
diff --git a/dtrans/source/cnttype/wbench/testcnttype.cxx b/dtrans/source/cnttype/wbench/testcnttype.cxx
index 7c2fe52..b35ae90 100644
--- a/dtrans/source/cnttype/wbench/testcnttype.cxx
+++ b/dtrans/source/cnttype/wbench/testcnttype.cxx
@@ -229,7 +229,7 @@ int SAL_CALL main( int nArgc, char* argv[] )
     OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
     Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-    // Print a message if an error occured.
+    // Print a message if an error occurred.
     if ( !g_xFactory.is( ) )
     {
         OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
diff --git a/dtrans/source/win32/dtobj/DataFmtTransl.cxx b/dtrans/source/win32/dtobj/DataFmtTransl.cxx
index 24897ff..09971a0 100644
--- a/dtrans/source/win32/dtobj/DataFmtTransl.cxx
+++ b/dtrans/source/win32/dtobj/DataFmtTransl.cxx
@@ -175,7 +175,7 @@ DataFlavor CDataFormatTranslator::getDataFlavorFromFormatEtc( const FORMATETC& a
                     OUString clipFormatName = getClipboardFormatName( aClipformat );
                     
                     // if we could not get a clipboard format name an
-                    // error must have occured or it is a standard
+                    // error must have occurred or it is a standard
                     // clipboard format that we don't translate, e.g.
                     // CF_BITMAP (the office only uses CF_DIB)
                     if ( clipFormatName.getLength( ) )
diff --git a/dtrans/source/win32/workbench/test_wincb.cxx b/dtrans/source/win32/workbench/test_wincb.cxx
index ac181f2..8cc3d1c 100644
--- a/dtrans/source/win32/workbench/test_wincb.cxx
+++ b/dtrans/source/win32/workbench/test_wincb.cxx
@@ -277,7 +277,7 @@ int SAL_CALL main( int nArgc, char* Argv[] )
     OUString rdbName = OUString( RTL_CONSTASCII_USTRINGPARAM( RDB_SYSPATH ) );
     Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-    // Print a message if an error occured.
+    // Print a message if an error occurred.
     if ( !g_xFactory.is( ) )
     {
         OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
diff --git a/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java b/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java
old mode 100755
new mode 100644
index 0ec343b..38f140a
--- a/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java
+++ b/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/Convert.java
@@ -177,10 +177,10 @@ public class Convert {
                     OutputHandler.closeAll();
                 
                 } catch(Exception e){
-                    System.out.print("An EXCEPTION occured, please check your commad line settings \n"+e.getMessage());
+                    System.out.print("An EXCEPTION occurred, please check your commad line settings \n"+e.getMessage());
                     System.exit(-1);
                 }catch(Throwable t){
-                    System.out.print("A FATAL ERROR occured, please check your commad line settings \n"+t.getMessage());
+                    System.out.print("A FATAL ERROR occurred, please check your commad line settings \n"+t.getMessage());
                     System.exit(-1);
                 }
 
@@ -455,7 +455,7 @@ public class Convert {
                 OutputHandler.out("ERROR: "+e.getMessage());
                 System.exit(-1);
             } catch (Throwable t){
-                System.out.print("An Error occured while parsing the command line,\n please check your commad line settings.\n "+t.getMessage());
+                System.out.print("An Error occurred while parsing the command line,\n please check your commad line settings.\n "+t.getMessage());
                 System.exit(-1);
             }
 
diff --git a/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java b/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java
old mode 100755
new mode 100644
index 9b5d0ac..0114ce5
--- a/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java
+++ b/l10ntools/java/l10nconv/java/com/sun/star/tooling/converter/SDFReader.java
@@ -585,7 +585,7 @@ public class SDFReader extends DataReader {
         if ((splitLine = line.split("\t")).length == 15)
             return splitLine;
         else
-            //an error occured
+            //an error occurred
             return null;
     }
 
diff --git a/l10ntools/source/filter/utils/Cache.java b/l10ntools/source/filter/utils/Cache.java
index f6f0b25..3278a6d 100644
--- a/l10ntools/source/filter/utils/Cache.java
+++ b/l10ntools/source/filter/utils/Cache.java
@@ -1795,7 +1795,7 @@ public class Cache
                 {
                     // last token was not a delimiter - new one is such delim
                     // => ignore this delimiter - but save the information, that
-                    //    it occured
+                    //    it occurred
                     bLastWasDelim = true;
                 }
             }
diff --git a/sot/source/sdstor/stgdir.cxx b/sot/source/sdstor/stgdir.cxx
index 0e61855..376264c 100644
--- a/sot/source/sdstor/stgdir.cxx
+++ b/sot/source/sdstor/stgdir.cxx
@@ -820,7 +820,7 @@ void StgDirStrm::SetupEntry( INT32 n, StgDirEntry* pUpper )
         {
             delete pCur;
             rIo.SetError( SVSTREAM_GENERALERROR );
-            // an error occured
+            // an error occurred
             return;
         }
 
diff --git a/svl/inc/svl/zforlist.hxx b/svl/inc/svl/zforlist.hxx
index c2c46f1..ed9abec 100644
--- a/svl/inc/svl/zforlist.hxx
+++ b/svl/inc/svl/zforlist.hxx
@@ -400,7 +400,7 @@ public:
         @return
             <TRUE/> if string new and ok and inserted.
              <FALSE/> if string already exists or an unresolvable parse error
-             occured, in which case nCheckPos is the error position within rString.
+             occurred, in which case nCheckPos is the error position within rString.
             If the error occurs at position 0 or rString is empty nCheckPos
             will be 1, so an error in the string is always indicated by
              nCheckPos not being zero.
diff --git a/svl/source/numbers/zformat.cxx b/svl/source/numbers/zformat.cxx
index 4c14323..adda1ac 100644
--- a/svl/source/numbers/zformat.cxx
+++ b/svl/source/numbers/zformat.cxx
@@ -613,7 +613,7 @@ SvNumberformat::SvNumberformat(String& rString,
         bStarFlag( FALSE )
 {
     // If the group (AKA thousand) separator is a Non-Breaking Space (French)
-    // replace all occurences by a simple space.
+    // replace all occurrences by a simple space.
     // The tokens will be changed to the LocaleData separator again later on.
     const sal_Unicode cNBSp = 0xA0;
     const String& rThSep = GetFormatter().GetNumThousandSep();
diff --git a/svtools/bmpmaker/bmp.cxx b/svtools/bmpmaker/bmp.cxx
index a742339..27788b7 100644
--- a/svtools/bmpmaker/bmp.cxx
+++ b/svtools/bmpmaker/bmp.cxx
@@ -170,7 +170,7 @@ void BmpApp::ShowUsage()
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "Usage:" ) ), EXIT_NOERROR );
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "    bmp srs_inputfile output_dir lang_dir lang_num -i input_dir [-i input_dir ][-f err_file]" ) ), EXIT_NOERROR );
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "Options:" ) ), EXIT_NOERROR );
-    Message( String( RTL_CONSTASCII_USTRINGPARAM( "   -i ...        name of directory to be searched for input files [multiple occurence is possible]" ) ), EXIT_NOERROR );
+    Message( String( RTL_CONSTASCII_USTRINGPARAM( "   -i ...        name of directory to be searched for input files [multiple occurrence is possible]" ) ), EXIT_NOERROR );
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "   -f            name of file, output should be written to" ) ), EXIT_NOERROR );
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "Examples:" ) ), EXIT_NOERROR );
     Message( String( RTL_CONSTASCII_USTRINGPARAM( "    bmp /home/test.srs /home/out enus 01 -i /home/res -f /home/out/bmp.err" ) ), EXIT_NOERROR );
diff --git a/svtools/source/brwbox/brwbox2.cxx b/svtools/source/brwbox/brwbox2.cxx
index cec50fc..f6c39ea 100644
--- a/svtools/source/brwbox/brwbox2.cxx
+++ b/svtools/source/brwbox/brwbox2.cxx
@@ -1538,7 +1538,7 @@ void BrowseBox::MouseButtonDown( const MouseEvent& rEvt )
         }
     }
 
-    // event occured out of data area
+    // event occurred out of data area
     if ( rEvt.IsRight() )
         pDataWin->Command(
             CommandEvent( Point( 1, LONG_MAX ), COMMAND_CONTEXTMENU, TRUE ) );
diff --git a/svtools/source/dialogs/addresstemplate.cxx b/svtools/source/dialogs/addresstemplate.cxx
index 1384c3f..d2ff68f 100644
--- a/svtools/source/dialogs/addresstemplate.cxx
+++ b/svtools/source/dialogs/addresstemplate.cxx
@@ -1263,7 +1263,7 @@ void AssignmentPersistentData::Commit()
         }
         catch(Exception&)
         {
-            DBG_ERROR("AddressBookSourceDialog::OnAdministrateDatasources: an error occured while executing the administration dialog!");
+            DBG_ERROR("AddressBookSourceDialog::OnAdministrateDatasources: an error occurred while executing the administration dialog!");
         }
 
         // re-fill the data source list
diff --git a/toolkit/qa/complex/toolkit/interface_tests/_XAccessibleComponent.java b/toolkit/qa/complex/toolkit/interface_tests/_XAccessibleComponent.java
old mode 100755
new mode 100644
index fc66e0b..1650e50
--- a/toolkit/qa/complex/toolkit/interface_tests/_XAccessibleComponent.java
+++ b/toolkit/qa/complex/toolkit/interface_tests/_XAccessibleComponent.java
@@ -386,7 +386,7 @@ public class _XAccessibleComponent {
     /**
      * Just calls the method. <p>
      *
-     * Has <b> OK </b> status if no runtime exceptions occured.
+     * Has <b> OK </b> status if no runtime exceptions occurred.
      */
     public boolean _grabFocus() {
 
@@ -401,7 +401,7 @@ public class _XAccessibleComponent {
      * component which support <code>XAccessibleComponent</code>.
      *
      * @return The array of children. Empty array returned if
-     * such children were not found or some error occured.
+     * such children were not found or some error occurred.
      */
     private XAccessibleComponent[] getChildrenComponents() {
         XAccessible xAcc = (XAccessible) UnoRuntime.queryInterface
@@ -439,7 +439,7 @@ public class _XAccessibleComponent {
      * <code>XAccessibleComponent</code>.
      *
      * @return The parent or <code>null</code> if the component
-     * has no parent or some errors occured.
+     * has no parent or some errors occurred.
      */
     private XAccessibleComponent getParentComponent() {
         XAccessible xAcc = (XAccessible) UnoRuntime.queryInterface
diff --git a/tools/source/fsys/dirent.cxx b/tools/source/fsys/dirent.cxx
index debb0fa..1a54b85 100644
--- a/tools/source/fsys/dirent.cxx
+++ b/tools/source/fsys/dirent.cxx
@@ -120,7 +120,7 @@ int Sys2SolarError_Impl( int nSysErr )
 #endif
     }
 
-    DBG_TRACE1( "FSys: unknown system error %d occured", nSysErr );
+    DBG_TRACE1( "FSys: unknown system error %d occurred", nSysErr );
     return FSYS_ERR_UNKNOWN;
 }
 
diff --git a/tools/source/fsys/os2.cxx b/tools/source/fsys/os2.cxx
index ca57f7d..7cc9cd2 100644
--- a/tools/source/fsys/os2.cxx
+++ b/tools/source/fsys/os2.cxx
@@ -112,7 +112,7 @@ int ApiRet2ToSolarError_Impl( int nApiRet )
         case ERROR_FILENAME_EXCED_RANGE:    return ERRCODE_IO_NAMETOOLONG;
     }
 
-    DBG_TRACE1( "FSys: unknown apiret error %d occured", nApiRet );
+    DBG_TRACE1( "FSys: unknown apiret error %d occurred", nApiRet );
     return FSYS_ERR_UNKNOWN;
 }
 
diff --git a/ucbhelper/inc/ucbhelper/resultset.hxx b/ucbhelper/inc/ucbhelper/resultset.hxx
index 3f1857c..5c7da9c 100644
--- a/ucbhelper/inc/ucbhelper/resultset.hxx
+++ b/ucbhelper/inc/ucbhelper/resultset.hxx
@@ -557,7 +557,7 @@ public:
 
     /**
      * This method will be called by the resultset implementation in order
-     * check, whether an error has occured while collecting data. The
+     * check, whether an error has occurred while collecting data. The
      * implementation of this method must throw an exception in that case.
      *
      * Note: An exception thrown to indicate an error must always be thrown
@@ -569,7 +569,7 @@ public:
      * In case data are obtained synchronously, the ResultSetException can
      * be thrown directly.
      *
-     * @exception ResultSetException thrown, if an error has occured
+     * @exception ResultSetException thrown, if an error has occurred
      */
     virtual void validate()
         throw( com::sun::star::ucb::ResultSetException ) = 0;
diff --git a/vcl/aqua/source/dtrans/test_aquacb.cxx b/vcl/aqua/source/dtrans/test_aquacb.cxx
index 70bed92..b5d677c 100644
--- a/vcl/aqua/source/dtrans/test_aquacb.cxx
+++ b/vcl/aqua/source/dtrans/test_aquacb.cxx
@@ -144,7 +144,7 @@ int SAL_CALL main( int argc, char** argv )
     OUString rdbName = OUString::createFromAscii( argv[1] );
     Reference< XMultiServiceFactory > g_xFactory( createRegistryServiceFactory( rdbName ) );
 
-    // Print a message if an error occured.
+    // Print a message if an error occurred.
     if ( !g_xFactory.is() )
     {
         OSL_ENSURE(sal_False, "Can't create RegistryServiceFactory");
diff --git a/vcl/inc/vcl/pdfwriter.hxx b/vcl/inc/vcl/pdfwriter.hxx
index c5d4dd1..e11a231 100644
--- a/vcl/inc/vcl/pdfwriter.hxx
+++ b/vcl/inc/vcl/pdfwriter.hxx
@@ -215,7 +215,7 @@ public:
         // PDF/A does not allow transparency
         Warning_Transparency_Omitted_PDFA,
 
-        // transparent object occured but is only supported since
+        // transparent object occurred but is only supported since
         // PDF 1.4
         Warning_Transparency_Omitted_PDF13,
 
@@ -657,9 +657,9 @@ The following structure describes the permissions used in PDF security
     bool Emit();
 
     /*
-     * Get a list of errors that occured during processing
+     * Get a list of errors that occurred during processing
      * this should enable the producer to give feedback about
-     * any anomalies that might have occured
+     * any anomalies that might have occurred
      */
     std::set< ErrorCode > GetErrors();
 
diff --git a/vcl/inc/vcl/print.hxx b/vcl/inc/vcl/print.hxx
index db41a16..10c31a6 100644
--- a/vcl/inc/vcl/print.hxx
+++ b/vcl/inc/vcl/print.hxx
@@ -552,7 +552,7 @@ class VCL_DLLPUBLIC PrinterOptionsHelper
     {}
 
     /* process a new set of properties
-     * merges changed properties and returns "true" if any occured
+     * merges changed properties and returns "true" if any occurred
      * if the optional output set is not NULL then the names of the changed properties are returned
     **/
     bool processProperties( const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& i_rNewProp,
diff --git a/vcl/inc/vcl/strhelper.hxx b/vcl/inc/vcl/strhelper.hxx
index a41cd65..43dc30b 100644
--- a/vcl/inc/vcl/strhelper.hxx
+++ b/vcl/inc/vcl/strhelper.hxx
@@ -49,7 +49,7 @@ int VCL_DLLPUBLIC GetCommandLineTokenCount( const ByteString& );
 
 String VCL_DLLPUBLIC WhitespaceToSpace( const String&, BOOL bProtect = TRUE );
 ByteString VCL_DLLPUBLIC WhitespaceToSpace( const ByteString&, BOOL bProtect = TRUE );
-// returns a string with multiple adjacent occurences of whitespace
+// returns a string with multiple adjacent occurrences of whitespace
 // converted to a single space. if bProtect is TRUE (nonzero), then
 // doublequote, singlequote and singleleftquote protect their respective
 // contents
diff --git a/vcl/source/control/ilstbox.cxx b/vcl/source/control/ilstbox.cxx
index b8a73ea..ae2cc47 100644
--- a/vcl/source/control/ilstbox.cxx
+++ b/vcl/source/control/ilstbox.cxx
@@ -233,8 +233,8 @@ USHORT ImplEntryList::InsertEntry( USHORT nPos, ImplEntryType* pNewEntry, BOOL b
         }
         catch (uno::RuntimeException& )
         {
-            // XXX this is arguable, if the exception occured because pNewEntry is
-            // garbage you wouldn't insert it. If the exception occured because the
+            // XXX this is arguable, if the exception occurred because pNewEntry is
+            // garbage you wouldn't insert it. If the exception occurred because the
             // Collator implementation is garbage then give the user a chance to see
             // his stuff
             Insert( pNewEntry, (ULONG)0 );
diff --git a/vcl/unx/gtk/app/gtkdata.cxx b/vcl/unx/gtk/app/gtkdata.cxx
index c92f67d..0c384b2 100644
--- a/vcl/unx/gtk/app/gtkdata.cxx
+++ b/vcl/unx/gtk/app/gtkdata.cxx
@@ -686,7 +686,7 @@ void GtkXLib::Init()
     SalI18N_KeyboardExtension *pKbdExtension = new SalI18N_KeyboardExtension( pDisp );
     XSync( pDisp, False );
 
-    pKbdExtension->UseExtension( ! HasXErrorOccured() );
+    pKbdExtension->UseExtension( ! HasXErrorOccurred() );
     PopXErrorLevel();
 
     m_pGtkSalDisplay->SetKbdExtension( pKbdExtension );
diff --git a/vcl/unx/inc/saldisp.hxx b/vcl/unx/inc/saldisp.hxx
index 0f3d3f3..16c76d3 100644
--- a/vcl/unx/inc/saldisp.hxx
+++ b/vcl/unx/inc/saldisp.hxx
@@ -245,9 +245,9 @@ public:
     virtual void    Remove( int fd );
 
     void			XError( Display *pDisp, XErrorEvent *pEvent );
-    bool            HasXErrorOccured() const { return m_aXErrorHandlerStack.back().m_bWas; }
+    bool            HasXErrorOccurred() const { return m_aXErrorHandlerStack.back().m_bWas; }
     unsigned int    GetLastXErrorRequestCode() const { return m_aXErrorHandlerStack.back().m_nLastErrorRequest; }
-    void            ResetXErrorOccured() { m_aXErrorHandlerStack.back().m_bWas = false; }
+    void            ResetXErrorOccurred() { m_aXErrorHandlerStack.back().m_bWas = false; }
     void PushXErrorLevel( bool bIgnore );
     void PopXErrorLevel();
 
diff --git a/vcl/unx/kde/kdedata.cxx b/vcl/unx/kde/kdedata.cxx
index 3630365..3204450 100644
--- a/vcl/unx/kde/kdedata.cxx
+++ b/vcl/unx/kde/kdedata.cxx
@@ -187,7 +187,7 @@ void KDEXLib::Init()
     SalI18N_KeyboardExtension *pKbdExtension = new SalI18N_KeyboardExtension( pDisp );
     XSync( pDisp, False );
 
-    pKbdExtension->UseExtension( ! HasXErrorOccured() );
+    pKbdExtension->UseExtension( ! HasXErrorOccurred() );
     PopXErrorLevel();
 
     pSalDisplay->SetKbdExtension( pKbdExtension );
diff --git a/vcl/unx/kde4/KDEXLib.cxx b/vcl/unx/kde4/KDEXLib.cxx
index 12cb886..6b585f7 100644
--- a/vcl/unx/kde4/KDEXLib.cxx
+++ b/vcl/unx/kde4/KDEXLib.cxx
@@ -184,7 +184,7 @@ void KDEXLib::Init()
     SalI18N_KeyboardExtension *pKbdExtension = new SalI18N_KeyboardExtension( pDisp );
     XSync( pDisp, False );
 
-    pKbdExtension->UseExtension( ! HasXErrorOccured() );
+    pKbdExtension->UseExtension( ! HasXErrorOccurred() );
     PopXErrorLevel();
 
     pSalDisplay->SetKbdExtension( pKbdExtension );
diff --git a/vcl/unx/source/app/saldata.cxx b/vcl/unx/source/app/saldata.cxx
index bfe96f7..a66dbdc 100644
--- a/vcl/unx/source/app/saldata.cxx
+++ b/vcl/unx/source/app/saldata.cxx
@@ -465,7 +465,7 @@ void SalXLib::Init()
     SalI18N_KeyboardExtension *pKbdExtension = new SalI18N_KeyboardExtension( pDisp );
     XSync( pDisp, False );
 
-    pKbdExtension->UseExtension( ! HasXErrorOccured() );
+    pKbdExtension->UseExtension( ! HasXErrorOccurred() );
     PopXErrorLevel();
 
     pSalDisplay->SetKbdExtension( pKbdExtension );
@@ -535,7 +535,7 @@ void SalXLib::XError( Display *pDisplay, XErrorEvent *pEvent )
             static Bool bOnce = False;
             if ( !bOnce )
             {
-                std::fprintf(stderr, "X-Error occured in a request for X_OpenFont\n");
+                std::fprintf(stderr, "X-Error occurred in a request for X_OpenFont\n");
                 EmitFontpathWarning();
 
                 bOnce = True ;
diff --git a/vcl/unx/source/app/saldisp.cxx b/vcl/unx/source/app/saldisp.cxx
index 2607bf6..129b1b9 100644
--- a/vcl/unx/source/app/saldisp.cxx
+++ b/vcl/unx/source/app/saldisp.cxx
@@ -2365,13 +2365,13 @@ void SalX11Display::Yield()
     Dispatch( &aEvent );
 
 #ifdef DBG_UTIL
-    if( pXLib_->HasXErrorOccured() )
+    if( pXLib_->HasXErrorOccurred() )
     {
         XFlush( pDisp_ );
         PrintEvent( "SalDisplay::Yield (WasXError)", &aEvent );
     }
 #endif
-    pXLib_->ResetXErrorOccured();
+    pXLib_->ResetXErrorOccurred();
 }
 
 long SalX11Display::Dispatch( XEvent *pEvent )
diff --git a/vcl/unx/source/app/wmadaptor.cxx b/vcl/unx/source/app/wmadaptor.cxx
index 0695884..112762b 100644
--- a/vcl/unx/source/app/wmadaptor.cxx
+++ b/vcl/unx/source/app/wmadaptor.cxx
@@ -669,7 +669,7 @@ GnomeWMAdaptor::GnomeWMAdaptor( SalDisplay* pSalDisplay ) :
                 && aRealType == XA_CARDINAL
                 && nFormat == 32
                 && nItems != 0
-                && ! m_pSalDisplay->GetXLib()->HasXErrorOccured()
+                && ! m_pSalDisplay->GetXLib()->HasXErrorOccurred()
                 )
             {
                 aCheckWindow =  *(XLIB_Window*)pProperty;
@@ -872,7 +872,7 @@ bool WMAdaptor::getNetWmName()
                 && aRealType == XA_WINDOW
                 && nFormat == 32
                 && nItems != 0
-                && ! m_pSalDisplay->GetXLib()->HasXErrorOccured()
+                && ! m_pSalDisplay->GetXLib()->HasXErrorOccurred()
                 )
             {
                 aCheckWindow =  *(XLIB_Window*)pProperty;
diff --git a/vcl/unx/source/gdi/salbmp.cxx b/vcl/unx/source/gdi/salbmp.cxx
index 7c14c72..1dadfdb 100644
--- a/vcl/unx/source/gdi/salbmp.cxx
+++ b/vcl/unx/source/gdi/salbmp.cxx
@@ -211,7 +211,7 @@ BitmapBuffer* X11SalBitmap::ImplCreateDIB( Drawable aDrawable,
         // so better catch the XError
         pXLib->PushXErrorLevel( true );
         XImage*	pImage = XGetImage( pXDisp, aDrawable, nX, nY, nWidth, nHeight, AllPlanes, ZPixmap );
-        bool bWasError = pXLib->HasXErrorOccured() && pXLib->GetLastXErrorRequestCode() == X_GetImage;
+        bool bWasError = pXLib->HasXErrorOccurred() && pXLib->GetLastXErrorRequestCode() == X_GetImage;
         pXLib->PopXErrorLevel();
 
         if( ! bWasError && pImage && pImage->data )
diff --git a/vcl/unx/source/window/FWS.cxx b/vcl/unx/source/window/FWS.cxx
index cb98a60..58ed7ad 100644
--- a/vcl/unx/source/window/FWS.cxx
+++ b/vcl/unx/source/window/FWS.cxx
@@ -191,7 +191,7 @@ WMSupportsFWS (Display *display, int screen)
  *
  * newHandler() -
  *
- * Handle X errors (temporarily) to record the occurance of BadWindow
+ * Handle X errors (temporarily) to record the occurrence of BadWindow
  * errors without crashing.  Used to detect the FWS_COMM_WINDOW root window
  * property containing an old or obsolete window id.
  *
diff --git a/vcl/unx/source/window/salframe.cxx b/vcl/unx/source/window/salframe.cxx
index 7ecc938..4310f2d 100644
--- a/vcl/unx/source/window/salframe.cxx
+++ b/vcl/unx/source/window/salframe.cxx
@@ -3753,7 +3753,7 @@ long X11SalFrame::HandleReparentEvent( XReparentEvent *pEvent )
                     &hDummy,
                     &Children,
                     &nChildren );
-        if( GetDisplay()->GetXLib()->HasXErrorOccured() )
+        if( GetDisplay()->GetXLib()->HasXErrorOccurred() )
         {
             hWM_Parent = GetShellWindow();
             break;
@@ -3843,7 +3843,7 @@ long X11SalFrame::HandleReparentEvent( XReparentEvent *pEvent )
      *  so need real geometries here
      *  (this will fail with virtual roots ?)
      */
-    GetDisplay()->GetXLib()->ResetXErrorOccured();
+    GetDisplay()->GetXLib()->ResetXErrorOccurred();
     int xp, yp, x, y;
     unsigned int wp, w, hp, h, bw, d;
     XGetGeometry( GetXDisplay(),
@@ -3855,7 +3855,7 @@ long X11SalFrame::HandleReparentEvent( XReparentEvent *pEvent )
                   &hRoot,
                   &xp, &yp, &wp, &hp, &bw, &d );
     bool bResized = false;
-    if( ! GetDisplay()->GetXLib()->HasXErrorOccured() )
+    if( ! GetDisplay()->GetXLib()->HasXErrorOccurred() )
     {
         maGeometry.nRightDecoration 	= wp - w - maGeometry.nLeftDecoration;
         maGeometry.nBottomDecoration	= hp - h - maGeometry.nTopDecoration;
diff --git a/vcl/unx/source/window/salobj.cxx b/vcl/unx/source/window/salobj.cxx
index bbe20d2..82ea7b1 100644
--- a/vcl/unx/source/window/salobj.cxx
+++ b/vcl/unx/source/window/salobj.cxx
@@ -149,7 +149,7 @@ X11SalObject* X11SalObject::CreateObject( SalFrame* pParent, SystemWindowData* p
                            pVisual,
                            CWEventMask|CWColormap, &aAttribs );
         XSync( pDisp, False );
-        BOOL bWasXError = pSalDisp->GetXLib()->HasXErrorOccured();
+        BOOL bWasXError = pSalDisp->GetXLib()->HasXErrorOccurred();
         pSalDisp->GetXLib()->PopXErrorLevel();
         if( bWasXError )
         {
@@ -176,7 +176,7 @@ X11SalObject* X11SalObject::CreateObject( SalFrame* pParent, SystemWindowData* p
     pObjData->pAppContext	= NULL;
 
     XSync(pDisp, False);
-    BOOL bWasXError = pSalDisp->GetXLib()->HasXErrorOccured();
+    BOOL bWasXError = pSalDisp->GetXLib()->HasXErrorOccurred();
     pSalDisp->GetXLib()->PopXErrorLevel();
     if( bWasXError )
     {
diff --git a/vcl/win/source/window/salframe.cxx b/vcl/win/source/window/salframe.cxx
index 76e4dd9..2625210 100644
--- a/vcl/win/source/window/salframe.cxx
+++ b/vcl/win/source/window/salframe.cxx
@@ -4935,7 +4935,7 @@ static int ImplMenuChar( HWND, WPARAM wParam, LPARAM lParam )
     if( nFound == 1 )
         nRet = MAKELRESULT( idxFound, MNC_EXECUTE );
     else
-        // duplicate mnemonics, just select the next occurence
+        // duplicate mnemonics, just select the next occurrence
         nRet = MAKELRESULT( idxFound, MNC_SELECT );
 
     return nRet;
@@ -5205,7 +5205,7 @@ static int ImplHandleMenuSelect( HWND hWnd, WPARAM wParam, LPARAM lParam )
     long nRet = 0;
     if ( hMenu && !pFrame->mLastActivatedhMenu )
     {
-        // we never activated a menu (ie, no WM_INITMENUPOPUP has occured yet)
+        // we never activated a menu (ie, no WM_INITMENUPOPUP has occurred yet)
         // which means this must be the menubar -> send activation/deactivation
         SalMenuEvent aMenuEvt;
         WinSalMenuItem *pSalMenuItem = ImplGetSalMenuItem( hMenu, nId, bByPosition );


More information about the Libreoffice-commits mailing list
diff --git a/sax/source/expatwrap/saxwriter.cxx b/sax/source/expatwrap/saxwriter.cxx
index a4c93a5..d5e6c63 100644
--- a/sax/source/expatwrap/saxwriter.cxx
+++ b/sax/source/expatwrap/saxwriter.cxx
@@ -1003,7 +1003,7 @@ public: // XServiceInfo
 private:
 
     void writeSequence( const Sequence<sal_Int8> & seq );
-    sal_Int32 getIndentPrefixLength( sal_Int32 nFirstLineBreakOccurence ) throw();
+    sal_Int32 getIndentPrefixLength( sal_Int32 nFirstLineBreakOccurrence ) throw();
 
     Reference< XOutputStream > 	m_out;
     Sequence < sal_Int8 > 		m_seqStartElement;
@@ -1047,14 +1047,14 @@ Sequence< OUString > 	SaxWriter_getSupportedServiceNames(void) throw()
 }
 
 
-sal_Int32 SAXWriter::getIndentPrefixLength( sal_Int32 nFirstLineBreakOccurence ) throw()
+sal_Int32 SAXWriter::getIndentPrefixLength( sal_Int32 nFirstLineBreakOccurrence ) throw()
 {
     sal_Int32 nLength =-1;
     if (mp_SaxWriterHelper)
     {
         if ( m_bForceLineBreak ||
             (m_bAllowLineBreak &&
-            ((nFirstLineBreakOccurence + mp_SaxWriterHelper->GetLastColumnCount()) > MAXCOLUMNCOUNT)) )
+            ((nFirstLineBreakOccurrence + mp_SaxWriterHelper->GetLastColumnCount()) > MAXCOLUMNCOUNT)) )
             nLength = m_nLevel;
     }
     m_bForceLineBreak = sal_False;
@@ -1258,19 +1258,19 @@ void SAXWriter::characters(const OUString& aChars) 	throw(SAXException, RuntimeE
             bThrowException = !mp_SaxWriterHelper->writeString( aChars, sal_False, sal_False );
         else
         {
             // Note : nFirstLineBreakOccurence is not exact, because we don't know, how
             //        many 2 and 3 byte chars are inbetween. However this whole stuff
             //        is eitherway for pretty printing only, so it does not need to be exact.
             sal_Int32 nLength(0);
             sal_Int32 nIndentPrefix(-1);
             if (m_bAllowLineBreak)
             {
-                sal_Int32 nFirstLineBreakOccurence = getFirstLineBreak( aChars );
+                sal_Int32 nFirstLineBreakOccurrence = getFirstLineBreak( aChars );
 
                 nLength = calcXMLByteLength( aChars.getStr(), aChars.getLength(),
                                                ! m_bIsCDATA , sal_False );
                 nIndentPrefix = getIndentPrefixLength(
-                    nFirstLineBreakOccurence >= 0 ? nFirstLineBreakOccurence : nLength );
+                    nFirstLineBreakOccurrence >= 0 ? nFirstLineBreakOccurrence : nLength );
             }
             else
                 nIndentPrefix = getIndentPrefixLength(nLength);
@@ -1258,19 +1258,19 @@ void SAXWriter::characters(const OUString& aChars) 	throw(SAXException, RuntimeE
         else
         {
-            // Note : nFirstLineBreakOccurence is not exact, because we don't know, how
+            // Note : nFirstLineBreakOccurrence is not exact, because we don't know, how
             //        many 2 and 3 byte chars are inbetween. However this whole stuff
             //        is eitherway for pretty printing only, so it does not need to be exact.